==> wawa-service-api-0.0.19-20180118.030028-24-sources.jar: cn/com/wawa/service/api/dto/ChargeBonusConfigDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;
import java.util.Date;

public class ChargeBonusConfigDto implements Serializable {

    private static final long serialVersionUID = -4353612780237241529L;


    private Long id;

    private Integer bonusType;

    private String title;

    private String detail;

    private Long chargeMoney;

    private Long bonusMoney;

    private Integer enable;

    private Long payload;

    private Date gmtCreate;

    private Date gmtModified;

    private Long maxVersionCode;

    private Long minVersionCode;

    private Integer clientType;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getBonusType() {
        return bonusType;
    }

    public void setBonusType(Integer bonusType) {
        this.bonusType = bonusType;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDetail() {
        return detail;
    }

    public void setDetail(String detail) {
        this.detail = detail;
    }

    public Long getChargeMoney() {
        return chargeMoney;
    }

    public void setChargeMoney(Long chargeMoney) {
        this.chargeMoney = chargeMoney;
    }

    public Long getBonusMoney() {
        return bonusMoney;
    }

    public void setBonusMoney(Long bonusMoney) {
        this.bonusMoney = bonusMoney;
    }

    public Integer getEnable() {
        return enable;
    }

    public void setEnable(Integer enable) {
        this.enable = enable;
    }

    public Long getPayload() {
        return payload;
    }

    public void setPayload(Long payload) {
        this.payload = payload;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getMaxVersionCode() {
        return maxVersionCode;
    }

    public void setMaxVersionCode(Long maxVersionCode) {
        this.maxVersionCode = maxVersionCode;
    }

    public Long getMinVersionCode() {
        return minVersionCode;
    }

    public void setMinVersionCode(Long minVersionCode) {
        this.minVersionCode = minVersionCode;
    }

    public Integer getClientType() {
        return clientType;
    }

    public void setClientType(Integer clientType) {
        this.clientType = clientType;
    }
}

==> wawa-service-api-0.0.31-sources.jar: cn/com/wawa/service/api/dto/ChargeBonusConfigDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;
import java.util.Date;

public class ChargeBonusConfigDto implements Serializable {

    private static final long serialVersionUID = -4353612780237241529L;


    private Long id;

    private Integer bonusType;

    private String title;

    private String detail;

    private Long chargeMoney;

    private Long bonusMoney;

    private Integer enable;

    private Long payload;

    private Date gmtCreate;

    private Date gmtModified;

    private Date openTime;

    private Date closeTime;

    private Long maxVersionCode;

    private Long minVersionCode;

    private Integer clientType;

    private Integer jumpStatus;

    private Integer hideAfterCharge;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getBonusType() {
        return bonusType;
    }

    public void setBonusType(Integer bonusType) {
        this.bonusType = bonusType;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDetail() {
        return detail;
    }

    public void setDetail(String detail) {
        this.detail = detail;
    }

    public Long getChargeMoney() {
        return chargeMoney;
    }

    public void setChargeMoney(Long chargeMoney) {
        this.chargeMoney = chargeMoney;
    }

    public Long getBonusMoney() {
        return bonusMoney;
    }

    public void setBonusMoney(Long bonusMoney) {
        this.bonusMoney = bonusMoney;
    }

    public Integer getEnable() {
        return enable;
    }

    public void setEnable(Integer enable) {
        this.enable = enable;
    }

    public Long getPayload() {
        return payload;
    }

    public void setPayload(Long payload) {
        this.payload = payload;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getMaxVersionCode() {
        return maxVersionCode;
    }

    public void setMaxVersionCode(Long maxVersionCode) {
        this.maxVersionCode = maxVersionCode;
    }

    public Long getMinVersionCode() {
        return minVersionCode;
    }

    public void setMinVersionCode(Long minVersionCode) {
        this.minVersionCode = minVersionCode;
    }

    public Integer getClientType() {
        return clientType;
    }

    public void setClientType(Integer clientType) {
        this.clientType = clientType;
    }

    public Date getOpenTime() {
        return openTime;
    }

    public void setOpenTime(Date openTime) {
        this.openTime = openTime;
    }

    public Date getCloseTime() {
        return closeTime;
    }

    public void setCloseTime(Date closeTime) {
        this.closeTime = closeTime;
    }

    public Integer getJumpStatus() {
        return jumpStatus;
    }

    public void setJumpStatus(Integer jumpStatus) {
        this.jumpStatus = jumpStatus;
    }

    public Integer getHideAfterCharge() {
        return hideAfterCharge;
    }

    public void setHideAfterCharge(Integer hideAfterCharge) {
        this.hideAfterCharge = hideAfterCharge;
    }
}
